@@ -19,7 +19,7 @@ use 5.020;
 use feature qw(say state lexical_subs);
 use feature 'lexical_subs'; no warnings "experimental::lexical_subs";
 package  Data::Dumper::Interp;
-$Data::Dumper::Interp::VERSION = '4.105';
+$Data::Dumper::Interp::VERSION = '4.106';
 
 package  # newline prevents Dist::Zilla::Plugin::PkgVersion from adding $VERSION
   DB;
@@ -248,6 +248,15 @@ sub dvisq(_){ @_=(&__getobj->Useqq(0),shift,'d');goto &_Interpolate }
 
 ############# only internals follow ############
 
+BEGIN {
+  if (! Data::Dumper->can("Maxrecurse")) { 
+    eval q(sub Maxrecurse { # Supply if missing in older Data::Dumper 
+             my($s, $v) = @_;
+             @_ == 2 ? (($s->{Maxrecurse} = $v), return $s) : $s->{Maxrecurse}//0;
+           });
+    die $@ if $@;
+  }
+}
 sub _config_defaults {
   my $self = shift;
 
